@@ -26,7 +26,7 @@ public:
     PreCommandJobPrivate(PrecommandJob *parent);
     QProcess *process = nullptr;
     QString precommand;
-    PrecommandJob *q;
+    PrecommandJob *const q;
 
     // Slots
     void slotFinished(int, QProcess::ExitStatus);
@@ -35,8 +35,7 @@ public:
 };
 
 PreCommandJobPrivate::PreCommandJobPrivate(PrecommandJob *parent)
-    : process(nullptr)
-    , q(parent)
+    : q(parent)
 {
 }
 
@@ -71,7 +70,7 @@ void PrecommandJob::start()
 void PreCommandJobPrivate::slotStarted()
 {
     Q_EMIT q->infoMessage(q, i18n("Executing precommand"),
-                        i18n("Executing precommand '%1'.", precommand));
+                          i18n("Executing precommand '%1'.", precommand));
 }
 
 void PreCommandJobPrivate::slotError(QProcess::ProcessError error)
