@@ -15,11 +15,11 @@
 AddTransportDialogNG_gui::AddTransportDialogNG_gui(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
     QPushButton *button = new QPushButton(QStringLiteral("Add transport"));
     layout->addWidget(button);
     connect(button, &QPushButton::clicked, this, [this] {
-        MailTransport::AddTransportDialogNG *dlg = new MailTransport::AddTransportDialogNG(this);
+        auto *dlg = new MailTransport::AddTransportDialogNG(this);
         dlg->exec();
         delete dlg;
     });
@@ -30,7 +30,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("addtransportnewng"));
     QStandardPaths::setTestModeEnabled(true);
-    AddTransportDialogNG_gui *t = new AddTransportDialogNG_gui();
+    auto *t = new AddTransportDialogNG_gui();
     t->show();
     app.exec();
     delete t;
