@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2006-2007 Volker Krause <vkrause@kde.org>
 
   Based on KMail code by:
   SPDX-FileCopyrightText: 2001-2003 Marc Mutz <mutz@kde.org>
@@ -24,7 +24,7 @@ public:
     Private(TransportManagementWidget *parent);
 
     Ui::TransportManagementWidget ui;
-    TransportManagementWidget *q;
+    TransportManagementWidget *const q;
 
     // Slots
     void defaultClicked();
@@ -133,10 +133,10 @@ void TransportManagementWidget::Private::removeClicked()
     }
     const int rc
         = KMessageBox::questionYesNo(
-        q,
-        i18n("Do you want to remove outgoing account '%1'?",
-             ui.transportList->currentItem()->text(0)),
-        i18n("Remove outgoing account?"));
+              q,
+              i18n("Do you want to remove outgoing account '%1'?",
+                   ui.transportList->currentItem()->text(0)),
+              i18n("Remove outgoing account?"));
     if (rc == KMessageBox::No) {
         return;
     }
