@@ -17,8 +17,7 @@ class AkonadiMailTransportPlugin : public MailTransport::TransportAbstractPlugin
 {
     Q_OBJECT
 public:
-    explicit AkonadiMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & =
-    {
+    explicit AkonadiMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & = {
     });
     ~AkonadiMailTransportPlugin() override;
 
